@@ -1,6 +1,6 @@
 package App::Prun::Scaled;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 1;
 
@@ -14,7 +14,7 @@ App::Prun::Scaled - Provides the sprun script as a command line interface to L<P
 
 =head1 VERSION
 
-Version 1.02
+Version 1.03
 
 =head1 SYNOPSYS
 
@@ -60,6 +60,11 @@ Ignore any failed processes, but do report to STDOUT any that fail.
 
   sprun -e -r -m 2 -M 8 -i 4 -u 3 command_file
 
+Test with the dummy_load script included in the contrib/ directory 
+of this distribution:
+
+  for F in `seq 1 100`; do echo "contrib/dummy_load"; done | sprun -v
+
 =head1 AUTHOR
 
 Jason McCarver <slam@parasite.cc>
